import * as React from 'react';
import { PureComponent } from 'react';
import { PropTypes } from 'prop-types';
import SyntaxHighlighter from 'react-syntax-highlighter';
import { normalizeLanguage, languageList } from './supportedLanguages';
import { applyTheme } from './themes/themeBuilder';
const allowedLanguagesList = languageList.concat('text');
export default class Code extends PureComponent {
    render() {
        const { language } = this.props;
        const { inlineCodeStyle } = applyTheme(this.props.theme);
        // @see https://github.com/conorhastings/react-syntax-highlighter/issues/87
        if (language === 'text') {
            return (React.createElement("span", { style: inlineCodeStyle.hljs },
                React.createElement("code", null, this.props.text)));
        }
        const props = {
            language: normalizeLanguage(language),
            PreTag: 'span',
            style: inlineCodeStyle,
            showLineNumbers: false
        };
        return (React.createElement(SyntaxHighlighter, Object.assign({}, props), this.props.text));
    }
}
Code.propTypes = {
    /** The code to be formatted */
    text: PropTypes.string.isRequired,
    /** The language in which the code is written */
    language: PropTypes.oneOf(allowedLanguagesList),
    /** A custom theme to be applied, implements the Theme interface */
    theme: PropTypes.object
};
Code.defaultProps = {
    theme: {},
};
//# sourceMappingURL=Code.js.map