"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
var React = require("react");
var react_1 = require("react");
var prop_types_1 = require("prop-types");
var react_syntax_highlighter_1 = require("react-syntax-highlighter");
var supportedLanguages_1 = require("./supportedLanguages");
var themeBuilder_1 = require("./themes/themeBuilder");
var CodeBlock = (function (_super) {
    tslib_1.__extends(CodeBlock, _super);
    function CodeBlock() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    CodeBlock.prototype.handleCopy = function (event) {
        /**
         * We don't want to copy the markup after highlighting, but rather the preformatted text in the selection
         */
        var data = event.nativeEvent.clipboardData;
        if (data) {
            event.preventDefault();
            var selectedText = window.getSelection().toString();
            var document_1 = "<!doctype html><html><head></head><body><pre>" + selectedText + "</pre></body></html>";
            data.clearData();
            data.setData('text/html', document_1);
            data.setData('text/plain', selectedText);
        }
    };
    CodeBlock.prototype.render = function () {
        var language = this.props.language;
        var _a = themeBuilder_1.applyTheme(this.props.theme), lineNumberContainerStyle = _a.lineNumberContainerStyle, codeBlockStyle = _a.codeBlockStyle, codeContainerStyle = _a.codeContainerStyle;
        var props = {
            language: supportedLanguages_1.normalizeLanguage(language),
            style: codeBlockStyle,
            showLineNumbers: this.props.showLineNumbers,
            PreTag: 'span',
            codeTagProps: { style: codeContainerStyle },
            lineNumberContainerStyle: lineNumberContainerStyle
        };
        var codeText = this.props.text.toString();
        return (React.createElement(react_syntax_highlighter_1.default, tslib_1.__assign({}, props, { onCopy: this.handleCopy }), codeText));
    };
    return CodeBlock;
}(react_1.PureComponent));
CodeBlock.displayName = 'CodeBlock';
CodeBlock.propTypes = {
    /** The code to be formatted */
    text: prop_types_1.PropTypes.string.isRequired,
    /** The language in which the code is written */
    language: prop_types_1.PropTypes.oneOf(supportedLanguages_1.languageList),
    /** Indicates whether or not to show line numbers */
    showLineNumbers: prop_types_1.PropTypes.bool,
    /** A custom theme to be applied, implements the Theme interface */
    theme: prop_types_1.PropTypes.object
};
CodeBlock.defaultProps = {
    showLineNumbers: true,
    language: 'md',
    theme: {}
};
exports.default = CodeBlock;
//# sourceMappingURL=CodeBlock.js.map